%% examples


%%
clear
close all


%% example 1

T1 = [3 0 0; 0 2 0; 0 0 1];
tform1old = maketform('affine', T1);
vistformfwd(tform1old, [0 100], [0 100]);

%%

tform1 = affine2d(T1);
vistformfwd(tform1, [0 100], [0 100]);

%% example 2

T2 = [1 0 0; 0.2 1 0; 0 0 1];
tform2 = affine2d(T2);
vistformfwd(tform2, [0 100], [0 100]);

%% example 3

Tscale = [1.5 0 0; 0 2 0; 0 0 1];
Trotation = [cos(pi/4) sin(pi/4) 0; 
	-sin(pi/4) cos(pi/4) 0;
	 0 0 1];
Tshear = [1 0 0; .2 1 0; 0 0 1];
T3 = Tscale * Trotation * Tshear;
tform3 = affine2d(T3); 
vistformfwd(tform3, [0 100], [0 100])


%% warp image (old style)

close all
f = checkerboard(50);
s = 0.8;
theta = pi/6;
T = [s*cos(theta) s*sin(theta) 0;
    -s*sin(theta) s*cos(theta) 0;
    0 0 1 ];
tform = maketform('affine',T);
g1 = imtransform(f,tform);
imshow(g1);
figure
g2 = imtransform(f,tform,'FillValue',0.5);
imshow(g2);

%% warp image (new style)

close all
f = checkerboard(50);
s = 0.8;
theta = pi/6;
T = [s*cos(theta) s*sin(theta) 0;
    -s*sin(theta) s*cos(theta) 0;
    0 0 1 ];
tform = affine2d(T);
[g1,ref]  = imwarp(f,tform);
imshow(g1);
ref
figure
g2 = imwarp(f,tform,'FillValues',0.5);
imshow(g2);


%% projective transform (old style)

close all
I = imread('cameraman.tif');
udata = [0 1];  vdata = [0 1];  % input coordinate system
tform = maketform('projective',[ 0 0;  1  0;  1  1; 0 1],...
                               [-4 2; -8 -3; -3 -5; 6 3]);
[B,xdata,ydata] = imtransform(I,tform,'bicubic','udata',udata,...
                              'vdata',vdata,...
                              'size',size(I),...
                              'fill',128);
subplot(1,2,1), imshow(I)
subplot(1,2,2), imshow(B)

%% projective transform (new style)

close all
I = imread('cameraman.tif');
inpts = [ 0 0;  1  0;  1  1; 0 1];
outpts = [-4 2; -8 -3; -3 -5; 6 3];
tform = fitgeotrans(inpts*255,outpts*255,'projective'); 
[B, ref1] = imwarp(I,tform); % ,'interp','bicubic');
ref1
xy = transformPointsForward(tform,inpts*255)
imshow(B);
 
%%

imageSize = [400 700];
xWorldLimits = [-2000 1500];
yWorldLimits = [-1200 800];
ref = imref2d(imageSize,xWorldLimits,yWorldLimits)
[B, ref2] = imwarp(I,tform,'OutputView',ref,'interp','bicubic','FillValues',128);
 ref2
% [B,xdata,ydata] = imtransform(I,tform2,'bicubic','udata',udata,...
%                               'vdata',vdata,...
%                               'size',size(I),...
%                               'fill',128);
subplot(1,2,1), imshow(I)
subplot(1,2,2), imshow(B)




